==> qpid-broker-plugins-connection-limits-9.2.0-sources.jar: org/apache/qpid/server/user/connection/limits/plugins/RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.qpid.server.user.connection.limits.plugins;

import static org.apache.qpid.server.security.access.Operation.INVOKE_METHOD;

import java.util.Map;
import java.util.concurrent.ExecutionException;

import com.google.common.util.concurrent.Futures;
import com.google.common.util.concurrent.ListenableFuture;

import org.apache.qpid.server.configuration.updater.Task;
import org.apache.qpid.server.util.FixedKeyMapCreator;

final class RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking extends RuleBasedBrokerConnectionLimitProviderImpl
{
    RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking(final Map<String, Object> attributes, final org.apache.qpid.server.model.ConfiguredObject<?> configuredobject)
    {
        super(attributes, configuredobject);
    }

    public java.util.Map<java.lang.String,java.lang.Object> getStatistics(final java.util.List<java.lang.String> statistics)
    {
        return super.getStatistics(statistics);
    }

    public java.lang.String setContextVariable(final java.lang.String name, final java.lang.String value)
    {
        return doSync(doOnConfigThread(new Task<ListenableFuture<java.lang.String>, RuntimeException>()
            {
                private String _args;
                @Override
                public ListenableFuture<java.lang.String> execute()
                {
                    return Futures.<java.lang.String>immediateFuture(RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.super.setContextVariable(name, value));
                }
                @Override
                public String getObject()
                {
                    return RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.this.toString();
                }
                @Override
                public String getAction()
                {
                    return "setContextVariable";
                }
                @Override
                public String getArguments()
                {
                    if (_args == null)
                    {
                        _args = "name=" + name + "," + "value=" + value;
                    }
                    return _args;
                }
            }));

    }

    public java.lang.String removeContextVariable(final java.lang.String name)
    {
        return doSync(doOnConfigThread(new Task<ListenableFuture<java.lang.String>, RuntimeException>()
            {
                private String _args;
                @Override
                public ListenableFuture<java.lang.String> execute()
                {
                    return Futures.<java.lang.String>immediateFuture(RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.super.removeContextVariable(name));
                }
                @Override
                public String getObject()
                {
                    return RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.this.toString();
                }
                @Override
                public String getAction()
                {
                    return "removeContextVariable";
                }
                @Override
                public String getArguments()
                {
                    if (_args == null)
                    {
                        _args = "name=" + name;
                    }
                    return _args;
                }
            }));

    }

    public org.apache.qpid.server.model.Content extractRules()
    {
        authorise(INVOKE_METHOD("extractRules"));

        return super.extractRules();
    }

    private static final FixedKeyMapCreator LOAD_FROM_FILE_MAP_CREATOR = new FixedKeyMapCreator("path");

    public void loadFromFile(final java.lang.String path)
    {
        authorise(INVOKE_METHOD("loadFromFile"), LOAD_FROM_FILE_MAP_CREATOR.createMap(path));

        doSync(doOnConfigThread(new Task<ListenableFuture<Void>, RuntimeException>()
            {
                private String _args;
                @Override
                public ListenableFuture<Void> execute()
                {
                    RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.super.loadFromFile(path);
                    return Futures.<Void>immediateFuture(null);
                }
                @Override
                public String getObject()
                {
                    return RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.this.toString();
                }
                @Override
                public String getAction()
                {
                    return "loadFromFile";
                }
                @Override
                public String getArguments()
                {
                    if (_args == null)
                    {
                        _args = "path=" + path;
                    }
                    return _args;
                }
            }));

    }

    public void clearRules()
    {
        authorise(INVOKE_METHOD("clearRules"));

        doSync(doOnConfigThread(new Task<ListenableFuture<Void>, RuntimeException>()
            {
                private String _args;
                @Override
                public ListenableFuture<Void> execute()
                {
                    RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.super.clearRules();
                    return Futures.<Void>immediateFuture(null);
                }
                @Override
                public String getObject()
                {
                    return RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.this.toString();
                }
                @Override
                public String getAction()
                {
                    return "clearRules";
                }
                @Override
                public String getArguments()
                {
                    return _args;
                }
            }));

    }

    public void resetCounters()
    {
        authorise(INVOKE_METHOD("resetCounters"));

        super.resetCounters();
    }

}

==> qpid-broker-plugins-connection-limits-10.0.1-sources.jar: org/apache/qpid/server/user/connection/limits/plugins/RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.qpid.server.user.connection.limits.plugins;

import static org.apache.qpid.server.security.access.Operation.INVOKE_METHOD;

import java.util.Map;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;

import org.apache.qpid.server.configuration.updater.Task;
import org.apache.qpid.server.util.FixedKeyMapCreator;

final class RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking extends RuleBasedBrokerConnectionLimitProviderImpl
{
    RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking(final Map<String, Object> attributes, final org.apache.qpid.server.model.ConfiguredObject<?> configuredobject)
    {
        super(attributes, configuredobject);
    }

    public java.util.Map<java.lang.String,java.lang.Object> getStatistics(final java.util.List<java.lang.String> statistics)
    {
        return super.getStatistics(statistics);
    }

    public java.lang.String setContextVariable(final java.lang.String name, final java.lang.String value)
    {
        return doSync(doOnConfigThread(new Task<CompletableFuture<java.lang.String>, RuntimeException>()
            {
                private String _args;
                @Override
                public CompletableFuture<java.lang.String> execute()
                {
                    return CompletableFuture.<java.lang.String>completedFuture(RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.super.setContextVariable(name, value));
                }
                @Override
                public String getObject()
                {
                    return RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.this.toString();
                }
                @Override
                public String getAction()
                {
                    return "setContextVariable";
                }
                @Override
                public String getArguments()
                {
                    if (_args == null)
                    {
                        _args = "name=" + name + "," + "value=" + value;
                    }
                    return _args;
                }
            }));

    }

    public java.lang.String removeContextVariable(final java.lang.String name)
    {
        return doSync(doOnConfigThread(new Task<CompletableFuture<java.lang.String>, RuntimeException>()
            {
                private String _args;
                @Override
                public CompletableFuture<java.lang.String> execute()
                {
                    return CompletableFuture.<java.lang.String>completedFuture(RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.super.removeContextVariable(name));
                }
                @Override
                public String getObject()
                {
                    return RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.this.toString();
                }
                @Override
                public String getAction()
                {
                    return "removeContextVariable";
                }
                @Override
                public String getArguments()
                {
                    if (_args == null)
                    {
                        _args = "name=" + name;
                    }
                    return _args;
                }
            }));

    }

    public org.apache.qpid.server.model.Content extractRules()
    {
        authorise(INVOKE_METHOD("extractRules"));

        return super.extractRules();
    }

    private static final FixedKeyMapCreator LOAD_FROM_FILE_MAP_CREATOR = new FixedKeyMapCreator("path");

    public void loadFromFile(final java.lang.String path)
    {
        authorise(INVOKE_METHOD("loadFromFile"), LOAD_FROM_FILE_MAP_CREATOR.createMap(path));

        doSync(doOnConfigThread(new Task<CompletableFuture<Void>, RuntimeException>()
            {
                private String _args;
                @Override
                public CompletableFuture<Void> execute()
                {
                    RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.super.loadFromFile(path);
                    return CompletableFuture.<Void>completedFuture(null);
                }
                @Override
                public String getObject()
                {
                    return RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.this.toString();
                }
                @Override
                public String getAction()
                {
                    return "loadFromFile";
                }
                @Override
                public String getArguments()
                {
                    if (_args == null)
                    {
                        _args = "path=" + path;
                    }
                    return _args;
                }
            }));

    }

    public void clearRules()
    {
        authorise(INVOKE_METHOD("clearRules"));

        doSync(doOnConfigThread(new Task<CompletableFuture<Void>, RuntimeException>()
            {
                private String _args;
                @Override
                public CompletableFuture<Void> execute()
                {
                    RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.super.clearRules();
                    return CompletableFuture.<Void>completedFuture(null);
                }
                @Override
                public String getObject()
                {
                    return RuleBasedBrokerConnectionLimitProviderImplWithAccessChecking.this.toString();
                }
                @Override
                public String getAction()
                {
                    return "clearRules";
                }
                @Override
                public String getArguments()
                {
                    return _args;
                }
            }));

    }

    public void resetCounters()
    {
        authorise(INVOKE_METHOD("resetCounters"));

        super.resetCounters();
    }

}
